@@ -1,6 +1,6 @@
 /*
-   Copyright 2011-2013, 2015 David Malcolm <dmalcolm@redhat.com>
-   Copyright 2011-2013, 2015 Red Hat, Inc.
+   Copyright 2011-2013, 2015, 2017 David Malcolm <dmalcolm@redhat.com>
+   Copyright 2011-2013, 2015, 2017 Red Hat, Inc.
 
    This is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
@@ -132,6 +132,9 @@ extern PyObject *
 PyGccPass_New(struct opt_pass *pass);
 
 /* gcc-python-location.c: */
+int
+PyGccLocation_init(PyGccLocation *self, PyObject *args, PyObject *kwargs);
+
 PyObject *
 PyGccLocation_repr(struct PyGccLocation * self);
 
@@ -144,6 +147,21 @@ PyGccLocation_richcompare(PyObject *o1, PyObject *o2, int op);
 long
 PyGccLocation_hash(struct PyGccLocation * self);
 
+PyObject *
+PyGccLocation_offset_column(PyGccLocation *self, PyObject *args);
+
+#if (GCC_VERSION >= 6000)
+
+PyObject *
+PyGccRichLocation_add_fixit_replace(PyGccRichLocation *self, PyObject *args,
+                                    PyObject *kwargs);
+
+int
+PyGccRichLocation_init(PyGccRichLocation *self, PyObject *args,
+                       PyObject *kwargs);
+
+#endif
+
 /* gcc-python-cfg.c: */
 PyObject *
 PyGccBasicBlock_repr(struct PyGccBasicBlock * self);
@@ -328,6 +346,11 @@ PyGccNamespaceDecl_declarations(tree t);
 PyObject *
 PyGccNamespaceDecl_namespaces(tree t);
 
+PyObject *
+PyGcc_GetFields(struct PyGccTree *self);
+
+PyObject *
+PyGcc_GetMethods(struct PyGccTree *self);
 
 /* gcc-python-gimple.c: */
 extern gcc_gimple_asm
@@ -481,6 +504,11 @@ PyGccRtl_str(struct PyGccRtl * self);
 PyObject *
 PyGcc_TreeListFromChain(tree t);
 
+PyObject *
+PyGcc_TreeListFromChainWithFilter(tree t,
+                                  int (*filter) (tree, void *),
+                                  void *user_data);
+
 PyObject *
 PyGcc_TreeMakeListFromTreeList(tree t);
 
